@@ -121,7 +121,6 @@ class CellAutomatRegression:
                     self.method not in methods,
                     self.number_items != None and self.number_items > self.data.shape[1], 
                     self.number_users != None and self.number_users > self.data.shape[0],
-                    self.threshold >= 1.0 or self.threshold <= 0.0,
                     self.number_items != None and self.number_items <= 0,
                     self.number_users != None and self.number_users <= 0,
                     self.round < 0]
@@ -130,7 +129,6 @@ class CellAutomatRegression:
                 f"Not found method {self.method}, try one of the available - {methods}", 
                 "Parameter 'number_items' is so large",
                 "Parameter 'number_users' is so large", 
-                "Parameter 'threshold' is error. Must be (0, 1)",
                 "Parametrt number_items must be [1, data.shape[1]",
                 "Parametrt number_users must be [1, data.shape[0]",
                 "Parameter round must be >= 0"]
